# Log4j-CVE-2021-44228 detector scanner playbook

[![CI](https://github.com/lucab85/log4j-cve-2021-44228/actions/workflows/ci.yml/badge.svg)](https://github.com/lucab85/log4j-cve-2021-44228/actions/workflows/ci.yml)

Ansible playbook to verify target Linux hosts using the official Red Hat Log4j detector script for Log4Shell (CVE-2021-44228).

[Red Hat version 1.2 detector 2021-12-20](https://access.redhat.com/security/vulnerabilities/RHSB-2021-009).

The result is saved in a txt file under `detector_dir` (default: `/opt/cve-2021-44228/`).

## Ansible Galaxy role

Code also available as Ansible Galaxy role [lucab85.ansible_role_log4shell](https://galaxy.ansible.com/lucab85/ansible_role_log4shell)

```bash
ansible-galaxy install lucab85.ansible_role_log4shell
```

## How to run the Ansible Playbook

Default variables scan all the `/var/` path for affected files.
You could customize the `vars.yml` file for more options.

```bash
ansible-playbook log4j-cve-2021-44228.yml
```

## Dependencies

None.

## Requirements

ansible 2.9+

## Variables vars.yml

default values:

```yaml
sh_detector: "cve-2021-44228--2021-12-20-1836.sh"
sh_signature: 'cve-2021-44228--2021-12-20-1836.sh.asc'
detector_baseurl: 'https://access.redhat.com/sites/default/files/'
detector_path: "/var/"
detector_dir: "/tmp/cve-2021-44228/"
detector_run_dir: 'tmp'
detector_options: '-n -d --no-progress --scan {{ detector_path }}'
gpg_keyid: '7514F77D8366B0D9'
gpg_public_key: 'gpg --keyserver pgp.mit.edu --recv {{ gpg_keyid }}'
clean_run_before: true
delete_after: false
verify_gpg: true
```

- sh_detector: the filename of the detector bash script file
- sh_signature: the filename of the detector GPG signature file
- detector_baseurl: the base URL to download the previous files
- detector_path: the path to inspect (default `/var/`)
- detector_dir: the download path of the detector (default `detector_dir`)
- detector_run_dir: the subdirectory to create before the run (default `tmp`)
- detector_options: the command lines options for detector script (default `-n -d --no-progress --scan {{ detector_path }}`)
- gpg_keyid: the GPG public key to download for the verification (default Red Hat Product Security `7514F77D8366B0D9`)
- clean_run_before: remove the run directory and recreate before the execution - detector requires an empty directory (default `true`)
- delete_after: remove the _detector_dir_ the execution (default `false`)
- verify_gpg: perform the GPG signature donwload and verification (default: `true`)


## Demo execution

The full output of the execution of the playbook against the RHEL8 demo target host:

```bash
$ ansible-playbook -i test/inventory log4j-cve-2021-44228.yml 

PLAY [download detector for Apache Log4j (CVE-2021-44228)] *****************************************************************************************************************************************

TASK [include_vars] ********************************************************************************************************************************************************************************
ok: [localhost]

TASK [print information] ***************************************************************************************************************************************************************************
ok: [localhost] => {
    "msg": "Ansible Playbook tested with detector version 1.2 released 2021-12-20.\nIf a 404 error occur please adjust the URL with the latest version available\nfor detector URL.\nPlease refer to the Red Hat Security Bullettin for up-to-date information and\nadjust the playbook variables accordingly.\nhttps://access.redhat.com/security/vulnerabilities/RHSB-2021-009.\n"
}

TASK [download detector] ***************************************************************************************************************************************************************************
ok: [localhost]

TASK [download detector signature] *****************************************************************************************************************************************************************
ok: [localhost]

PLAY [detector for Apache Log4j (CVE-2021-44228)] **************************************************************************************************************************************************

TASK [include_vars] ********************************************************************************************************************************************************************************
ok: [demo.example.com]

TASK [dependency present] **************************************************************************************************************************************************************************
ok: [demo.example.com]

TASK [create detector directory] *******************************************************************************************************************************************************************
changed: [demo.example.com]

TASK [copy detector file] **************************************************************************************************************************************************************************
changed: [demo.example.com]

TASK [copy detector signature] *********************************************************************************************************************************************************************
changed: [demo.example.com]

TASK [gpg public key] ******************************************************************************************************************************************************************************
changed: [demo.example.com]

TASK [gpg verify detector] *************************************************************************************************************************************************************************
changed: [demo.example.com]

TASK [remove any detector run directory] ***********************************************************************************************************************************************************
ok: [demo.example.com]

TASK [create detector run directory] ***************************************************************************************************************************************************************
changed: [demo.example.com]

TASK [run detector/scanner] ************************************************************************************************************************************************************************
changed: [demo.example.com]

TASK [files in detector run directory] *************************************************************************************************************************************************************
ok: [demo.example.com]

TASK [print vulnerable path(s) found] **************************************************************************************************************************************************************
ok: [demo.example.com] => {
    "vulnerable": {
        "changed": false,
        "examined": 1,
        "failed": false,
        "files": [],
        "matched": 0,
        "msg": "All paths examined",
        "skipped_paths": {}
    }
}

TASK [remove detector directory] *******************************************************************************************************************************************************************
skipping: [demo.example.com]

PLAY RECAP *****************************************************************************************************************************************************************************************
demo.example.com           : ok=12   changed=7    unreachable=0    failed=0    skipped=1    rescued=0    ignored=0   
localhost                  : ok=4    changed=0    unreachable=0    failed=0    skipped=0    rescued=0    ignored=0
```

## License

MIT / BSD

## Author Information

This role was created in 2021 by [Luca Berton](https://www.lucaberton.it/), author of [Ansible Pilot](https://www.ansiblepilot.com/).

## Ansible Pilot

More information

- [Website](https://www.ansiblepilot.com/)
- [Ansible Pilot YouTube channel](https://www.youtube.com/channel/UC5MNbTYRHSCu9vAki3z9SmA)
- [Medium](https://ansiblepilot.medium.com/)
- [Twitter](https://twitter.com/ansiblepilot)

## Donate

Thank you for supporting me

- [Patreon](https://patreon.com/lucaberton)
- [Buy me a pizza](https://www.buymeacoffee.com/lucab)
- [GitHub sponsor](https://github.com/sponsors/lucab85)
